=============
Configuration
=============

IoTronic Panels has no configuration option.

For more configurations, see
`Deployment & Configuration
<https://docs.openstack.org/horizon/latest/configuration/index.html>`__
in the Horizon documentation.
